"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ExerciseRecord = void 0;
const errors_1 = require("../utils/errors");
const db_1 = require("../utils/db");
const uuid_1 = require("uuid");
class ExerciseRecord {
    constructor(obj) {
        if (!obj.order || obj.order.length > 12) {
            throw new errors_1.ValidationError('Należy podać kolejność wykonywania ćwiczeń o długości max. 12 znaków.');
        }
        if (!obj.name || obj.name.length > 32) {
            throw new errors_1.ValidationError('Należy podać nazwę ćwiczenia o długości max. 32 znaków.');
        }
        if (!obj.series || obj.series.length > 10) {
            throw new errors_1.ValidationError('Należy podać ilość serii lub ich zakres o długości max. 10 znaków.');
        }
        if (!obj.repetitions || obj.repetitions.length > 20) {
            throw new errors_1.ValidationError('Należy podać ilość powtórzeń lub ich zakres o długości max. 20 znaków.');
        }
        if (!obj.pause || obj.pause.length > 20) {
            throw new errors_1.ValidationError('Należy podać długość przerwy między seriami lub jej zakres o długości max. 20 znaków.');
        }
        if (!obj.tips || obj.tips.length > 500) {
            throw new errors_1.ValidationError('Należy podać wskazówki dotyczące ćwiczeń o długości max. 500 znaków.');
        }
        if (!obj.url || obj.url.length > 130) {
            throw new errors_1.ValidationError('Link do ćwiczenia nie może przekraczać 130 znaków.');
        }
        this.id = obj.id;
        this.order = obj.order;
        this.name = obj.name;
        this.series = obj.series;
        this.repetitions = obj.repetitions;
        this.pause = obj.pause;
        this.tips = obj.tips;
        this.url = obj.url;
        this.partId = obj.partId;
        this.createdAt = obj.createdAt;
    }
    static findAll() {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `plans` ORDER BY `createdAt` ASC");
            return results.map(obj => new ExerciseRecord(obj));
        });
    }
    static findAllWithPartId(partId) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `plans` WHERE `partId` = :partId ORDER BY `createdAt` ASC", {
                partId,
            });
            return results.map(obj => new ExerciseRecord(obj));
        });
    }
    static getOne(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * from `plans` WHERE `id` = :id", {
                id,
            });
            return results.length === 0 ? null : new ExerciseRecord(results[0]);
        });
    }
    insert() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.id || !this.createdAt) {
                this.id = (0, uuid_1.v4)();
                this.createdAt = new Date();
            }
            else {
                throw new Error('Nie można dodać czegoś, co już istnieje.');
            }
            yield db_1.pool.execute("INSERT INTO `plans`(`id`, `order`, `name`, `series`, `repetitions`, `pause`, `tips`, `url`, `partId`, `createdAt`) VALUES(:id, :order, :name, :series, :repetitions, :pause, :tips, :url, :partId, :createdAt)", this);
            return this.id;
        });
    }
    update() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("UPDATE `plans` SET `order` = :order, `name` = :name, `series` = :series, `repetitions` = :repetitions, `pause` = :pause, `tips` = :tips, `url` = :url, `partId` = :partId WHERE `id` = :id", {
                id: this.id,
                order: this.order,
                name: this.name,
                series: this.series,
                repetitions: this.repetitions,
                pause: this.pause,
                tips: this.tips,
                url: this.url,
                partId: this.partId,
            });
        });
    }
    delete() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("DELETE FROM `plans` WHERE `id` = :id", {
                id: this.id,
            });
        });
    }
}
exports.ExerciseRecord = ExerciseRecord;
//# sourceMappingURL=exercise.record.js.map