"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.PartOfPlanRecord = void 0;
const errors_1 = require("../utils/errors");
const db_1 = require("../utils/db");
const uuid_1 = require("uuid");
const slugify_1 = require("../utils/slugify");
class PartOfPlanRecord {
    constructor(obj, existingSlugs = []) {
        if (!obj.name || obj.name.length > 50) {
            throw new errors_1.ValidationError('Należy podać nazwę części planu o długości max. 50 znaków.');
        }
        this.id = obj.id;
        this.name = obj.name;
        this.slug = (0, slugify_1.slugify)(obj.slug || obj.name, existingSlugs);
        this.createdAt = obj.createdAt;
    }
    static findAll() {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `parts_of_plan` ORDER BY `createdAt` ASC");
            return results.map(obj => new PartOfPlanRecord(obj));
        });
    }
    static findAllWithSlug(slug) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `parts_of_plan` WHERE `slug` = :slug ORDER BY `createdAt` ASC", {
                slug,
            });
            return results.map(obj => new PartOfPlanRecord(obj));
        });
    }
    static getOne(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * from `parts_of_plan` WHERE `id` = :id", {
                id,
            });
            return results.length === 0 ? null : new PartOfPlanRecord(results[0]);
        });
    }
    insert() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.id || !this.createdAt) {
                this.id = (0, uuid_1.v4)();
                this.createdAt = new Date();
            }
            else {
                throw new Error('Nie można dodać czegoś, co już istnieje.');
            }
            if (!this.slug) {
                const [results] = yield db_1.pool.execute("SELECT `slug` FROM `parts_of_plan`");
                const existingSlugs = results.map((row) => row.slug);
                this.slug = (0, slugify_1.slugify)(this.slug || this.name, existingSlugs);
            }
            yield db_1.pool.execute("INSERT INTO `parts_of_plan`(`id`, `name`, `slug`, `createdAt`) VALUES(:id, :name, :slug, :createdAt)", this);
            return this.id;
        });
    }
    update() {
        return __awaiter(this, void 0, void 0, function* () {
            const [rows] = yield db_1.pool.execute("SELECT `slug` FROM `parts_of_plan`");
            const existingSlugs = rows.map(row => row.slug);
            const newSlug = (0, slugify_1.slugify)(this.slug || this.name, existingSlugs);
            if (newSlug !== this.slug) {
                this.slug = newSlug;
            }
            yield db_1.pool.execute("UPDATE `parts_of_plan` SET `name` = :name, `slug` = :slug WHERE `id` = :id", {
                id: this.id,
                name: this.name,
                slug: this.slug,
            });
        });
    }
    delete() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("DELETE FROM `parts_of_plan` WHERE `id` = :id", {
                id: this.id,
            });
        });
    }
}
exports.PartOfPlanRecord = PartOfPlanRecord;
//# sourceMappingURL=part-of-plan.record.js.map