"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.exerciseRouter = void 0;
const express_1 = require("express");
const exercise_record_1 = require("../records/exercise.record");
const errors_1 = require("../utils/errors");
const DOMPurify = require('isomorphic-dompurify');
exports.exerciseRouter = (0, express_1.Router)()
    .get('/exercises', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    if (typeof req.query.partId === 'string') {
        return res.json(yield exercise_record_1.ExerciseRecord.findAllWithPartId(DOMPurify.sanitize(req.query.partId)));
    }
    return res.json(yield exercise_record_1.ExerciseRecord.findAll());
}))
    .get('/exercises/:id', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const exercise = yield exercise_record_1.ExerciseRecord.getOne(req.params.id);
    res.json(exercise);
}))
    .post('/exercises', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const exercise = new exercise_record_1.ExerciseRecord(req.body);
    yield exercise.insert();
    res.json(exercise);
}))
    .delete('/exercises/:id', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const exercise = yield exercise_record_1.ExerciseRecord.getOne(req.params.id);
    if (!exercise) {
        throw new errors_1.ValidationError('Nie znaleziono takiego ćwiczenia.');
    }
    yield exercise.delete();
    res.end();
}))
    .put('/exercises/:id', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const exercise = yield exercise_record_1.ExerciseRecord.getOne(req.params.id);
    if (exercise === null) {
        throw new errors_1.ValidationError('Nie znaleziono takiego ćwiczenia.');
    }
    exercise.order = DOMPurify.sanitize(req.body.order);
    exercise.name = DOMPurify.sanitize(req.body.name);
    exercise.series = DOMPurify.sanitize(req.body.series);
    exercise.repetitions = DOMPurify.sanitize(req.body.repetitions);
    exercise.pause = DOMPurify.sanitize(req.body.pause);
    exercise.tips = DOMPurify.sanitize(req.body.tips);
    exercise.url = DOMPurify.sanitize(req.body.url);
    exercise.partId = DOMPurify.sanitize(req.body.partId);
    yield exercise.update();
    res.json(exercise);
}));
//# sourceMappingURL=exercise.router.js.map