"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const exercise_record_1 = require("../../records/exercise.record");
const db_1 = require("../../utils/db");
const defaultObj = {
    order: '1',
    name: 'romanian deadlift',
    series: '4',
    repetitions: '8',
    pause: '120-180s',
    tips: '*guma wokół bioder, z odważnikiem kettlebell oburącz, wolno w dół (3-4 sekundy)',
    url: 'https://www.youtube.com/watch?v=ZFgjmDzj5m4',
    partId: 'eb717598-8437-4d8d-825e-d8d3f1fbead3',
};
afterAll(() => __awaiter(void 0, void 0, void 0, function* () {
    yield db_1.pool.end();
}));
test('ExerciseRecord.getOne returns data from database for one entry.', () => __awaiter(void 0, void 0, void 0, function* () {
    const exercise = yield exercise_record_1.ExerciseRecord.getOne('15adcb1a-5136-4644-a70d-bf91d7119794');
    expect(exercise).toBeDefined();
    expect(exercise.id).toBe('15adcb1a-5136-4644-a70d-bf91d7119794');
    expect(exercise.name).toBe('romanian deadlift');
}));
test('ExerciseRecord.getOne returns null from database for unexisting entry.', () => __awaiter(void 0, void 0, void 0, function* () {
    const exercise = yield exercise_record_1.ExerciseRecord.getOne('---');
    expect(exercise).toBeNull();
}));
test('ExerciseRecord.findAll returns array of found entries.', () => __awaiter(void 0, void 0, void 0, function* () {
    const exercises = yield exercise_record_1.ExerciseRecord.findAll();
    expect(exercises).not.toEqual([]);
    expect(exercises[0].id).toBeDefined();
}));
test('ExerciseRecord.findAllWithPartId returns array of found entries with partId from req.query.', () => __awaiter(void 0, void 0, void 0, function* () {
    const exercises = yield exercise_record_1.ExerciseRecord.findAllWithPartId(defaultObj.partId);
    expect(exercises).not.toEqual([]);
    expect(exercises[0].id).toBeDefined();
}));
test('ExerciseRecord.findAllWithPartId returns empty array when searching for something that does not exists.', () => __awaiter(void 0, void 0, void 0, function* () {
    const ads = yield exercise_record_1.ExerciseRecord.findAllWithPartId('---------------------------------------');
    expect(ads).toEqual([]);
}));
test('ExerciseRecord.insert returns new UUID.', () => __awaiter(void 0, void 0, void 0, function* () {
    const exercise = new exercise_record_1.ExerciseRecord(defaultObj);
    yield exercise.insert();
    expect(exercise.id).toBeDefined();
    expect(typeof exercise.id).toBe('string');
}));
test('ExerciseRecord.insert inserts data to database', () => __awaiter(void 0, void 0, void 0, function* () {
    const exercise = new exercise_record_1.ExerciseRecord(defaultObj);
    yield exercise.insert();
    const foundExercise = yield exercise_record_1.ExerciseRecord.getOne(exercise.id);
    expect(foundExercise).toBeDefined();
    expect(foundExercise).not.toBeNull();
    expect(foundExercise.id).toBe(exercise.id);
}));
//# sourceMappingURL=exercise.test.js.map