"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DetailRecord = void 0;
const errors_1 = require("../utils/errors");
const db_1 = require("../utils/db");
const uuid_1 = require("uuid");
class DetailRecord {
    constructor(obj) {
        if (!obj.length || obj.length.length > 34) {
            throw new errors_1.ValidationError('Należy podać długość cyklu - max. 34 znaki.');
        }
        if (!obj.frequency || obj.frequency.length > 34) {
            throw new errors_1.ValidationError('Należy podać częstotliwość treningów o długości max. 34 znaków.');
        }
        if (!obj.schedule || obj.schedule.length > 34) {
            throw new errors_1.ValidationError('Należy podać rozkład treningów o max. 34 znaków.');
        }
        this.id = obj.id;
        this.length = obj.length;
        this.frequency = obj.frequency;
        this.schedule = obj.schedule;
    }
    static findAll() {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `plan_details`");
            return results.map(obj => new DetailRecord(obj));
        });
    }
    static getOne(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * from `plan_details` WHERE `id` = :id", {
                id,
            });
            return results.length === 0 ? null : new DetailRecord(results[0]);
        });
    }
    update() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.id) {
                this.id = (0, uuid_1.v4)();
            }
            yield db_1.pool.execute("UPDATE `plan_details` SET `length` = :length, `frequency` = :frequency, `schedule` = :schedule WHERE `id` = :id", {
                id: this.id,
                length: this.length,
                frequency: this.frequency,
                schedule: this.schedule,
            });
        });
    }
}
exports.DetailRecord = DetailRecord;
//# sourceMappingURL=detail.record.js.map