"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.RuleRecord = void 0;
const errors_1 = require("../utils/errors");
const db_1 = require("../utils/db");
const uuid_1 = require("uuid");
class RuleRecord {
    constructor(obj) {
        if (!obj.rule || obj.rule.length > 500) {
            throw new errors_1.ValidationError('Należy podać zasadę progresji o długości max. 500 znaków.');
        }
        this.id = obj.id;
        this.rule = obj.rule;
        this.createdAt = obj.createdAt;
    }
    static findAll() {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `progression_rules` ORDER BY `createdAt` ASC");
            return results.map(obj => new RuleRecord(obj));
        });
    }
    static getOne(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * from `progression_rules` WHERE `id` = :id", {
                id,
            });
            return results.length === 0 ? null : new RuleRecord(results[0]);
        });
    }
    insert() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.id || !this.createdAt) {
                this.id = (0, uuid_1.v4)();
                this.createdAt = new Date();
            }
            else {
                throw new Error('Nie można dodać czegoś, co już istnieje.');
            }
            yield db_1.pool.execute("INSERT INTO `progression_rules`(`id`, `rule`, `createdAt`) VALUES(:id, :rule, :createdAt)", this);
        });
    }
    update() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("UPDATE `progression_rules` SET `rule` = :rule WHERE `id` = :id", {
                id: this.id,
                rule: this.rule,
            });
        });
    }
    delete() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("DELETE FROM `progression_rules` WHERE `id` = :id", {
                id: this.id,
            });
        });
    }
}
exports.RuleRecord = RuleRecord;
//# sourceMappingURL=rule.record.js.map