"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.partOfPlanRouter = void 0;
const express_1 = require("express");
const part_of_plan_record_1 = require("../records/part-of-plan.record");
const errors_1 = require("../utils/errors");
const DOMPurify = require('isomorphic-dompurify');
exports.partOfPlanRouter = (0, express_1.Router)()
    .get('/plans', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    if (typeof req.query.slug === 'string') {
        return res.json(yield part_of_plan_record_1.PartOfPlanRecord.findAllWithSlug(DOMPurify.sanitize(req.query.slug)));
    }
    return res.json(yield part_of_plan_record_1.PartOfPlanRecord.findAll());
}))
    .get('/plans/:id', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const part = yield part_of_plan_record_1.PartOfPlanRecord.getOne(req.params.id);
    res.json(part);
}))
    .post('/plans', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const part = new part_of_plan_record_1.PartOfPlanRecord(req.body);
    yield part.insert();
    res.json(part);
}))
    .delete('/plans/:id', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const part = yield part_of_plan_record_1.PartOfPlanRecord.getOne(req.params.id);
    if (!part) {
        throw new errors_1.ValidationError('Nie znaleziono takiej części planu.');
    }
    yield part.delete();
    res.end();
}))
    .put('/plans/:id', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const part = yield part_of_plan_record_1.PartOfPlanRecord.getOne(req.params.id);
    if (part === null) {
        throw new errors_1.ValidationError('Nie znaleziono takiej części planu.');
    }
    part.name = DOMPurify.sanitize(req.body.name);
    part.slug = DOMPurify.sanitize(req.body.slug);
    yield part.update();
    res.json(part);
}));
//# sourceMappingURL=part-of-plan.router.js.map